*$ CREATE FORMFU.FOR
*COPY FORMFU
*                                                                      *
*=== formfu ===========================================================*
*                                                                      *
      DOUBLE PRECISION FUNCTION FORMFU ( IJ, QU2, ZMEDIU, AMEDIU )

      INCLUDE '(DBLPRC)'
      INCLUDE '(DIMPAR)'
      INCLUDE '(IOUNIT)'
*
*----------------------------------------------------------------------*
*                                                                      *
*     Copyright (C) 2005           by    Alfredo Ferrari & Paola Sala  *
*     All Rights Reserved.                                             *
*                                                                      *
*                                                                      *
*     User-Provided Form Factor : can be used to OVERRIDE standard     *
*                                 Fluka Form Factors                   *
*                                                                      *
*     Created on  25 july 2005   by    Alfredo Ferrari & Paola Sala    *
*                                                   Infn - Milan       *
*                                                                      *
*     Last change on 25-jul-2005     by   Paola Sala                   *
*                                                                      *
*     Input variables:                                                 *
*           Ij  = particle code (Paprop numbering).                    *
*                                   set to 3 for both e+ and e-        *
*           Qu2 = squared momentum transfer (GeV/c)**2                 *
*        Amediu = atomic mass of target nucleus                        *
*        Zmediu = atomic number of target nucleus                      *
*     Return value:                                                    *
*              squared value of the nuclear charge form factor         *
*              (assumed to be 1 for Qu2=0)                             *
*              if negative, the standard calculation is used           *
*                                                                      *
*----------------------------------------------------------------------*
*
*  Default : returns negative value, FLUKA internal form factors used
      FORMFU = - ONEONE
      RETURN
*=== End of function Formfu ===========================================*
      END
